Finally https://launchpad.net/ubuntu/+source/llvm-
toolchain-22/1:22.1.6-1ubuntu4/+build/33583621 finished and makes this
complete.

There was also this cleanup from the interim version that never fully
built on all versions:

old binaries left on amd64: libllvm-22-ocaml-dev (from 1:22.1.6-1ubuntu3)
old binaries left on amd64v3: libllvm-22-ocaml-dev (from 1:22.1.6-1ubuntu3)
old binaries left on arm64: libllvm-22-ocaml-dev (from 1:22.1.6-1ubuntu3)
old binaries left on ppc64el: libllvm-22-ocaml-dev (from 1:22.1.6-1ubuntu3)
old binaries left on riscv64: libllvm-22-ocaml-dev (from 1:22.1.6-1ubuntu2)
old binaries left on s390x: libllvm-22-ocaml-dev (from 1:22.1.6-1ubuntu3)

Cleaned those as well

AFAICS someone promoted llvm-toolchain-22 in stonking-release but the one in 
proposed is not yet.
IIRC the dependency from bpftrace was libclang-cpp22 libclang1-22 libllvm22

Those I see like this

$rmadison -u ubuntu -s stonking,stonking-proposed -a amd64 libclang-cpp22 
libclang1-22 libllvm22 
 libclang-cpp22 | 1:22.1.6-1ubuntu1 | stonking                   | amd64
 libclang-cpp22 | 1:22.1.6-1ubuntu4 | stonking-proposed/universe | amd64
 libclang1-22   | 1:22.1.6-1ubuntu1 | stonking                   | amd64
 libclang1-22   | 1:22.1.6-1ubuntu4 | stonking-proposed/universe | amd64
 libllvm22      | 1:22.1.6-1ubuntu1 | stonking                   | amd64
 libllvm22      | 1:22.1.6-1ubuntu4 | stonking-proposed/universe | amd64

I rechecked the one in stonking-release and it is exactly those three
for now.

Mismatches also lists it as "Source only movements to main (foundations-
bugs)"


Due to all of the above I'm cleaning up all of the above by the following three 
steps:

1. removing the old binaries no more built

rmadison -u ubuntu -s stonking,stonking-proposed libllvm-22-ocaml-dev
 libllvm-22-ocaml-dev | 1:22.1.6-1ubuntu1 | stonking/universe          | amd64, 
amd64v3, arm64, ppc64el, riscv64, s390x
 libllvm-22-ocaml-dev | 1:22.1.6-1ubuntu2 | stonking-proposed/universe | riscv64
 libllvm-22-ocaml-dev | 1:22.1.6-1ubuntu3 | stonking-proposed/universe | amd64, 
amd64v3, arm64, ppc64el, s390x

./remove-package -m "No more built by llvm-toolchain-22 1:22.1.6-1ubuntu4" -d 
ubuntu -s stonking-proposed --binary libllvm-22-ocaml-dev
Removing packages from stonking-proposed:
        libllvm-22-ocaml-dev 1:22.1.6-1ubuntu3 in stonking amd64
        libllvm-22-ocaml-dev 1:22.1.6-1ubuntu3 in stonking amd64v3
        libllvm-22-ocaml-dev 1:22.1.6-1ubuntu3 in stonking arm64
        libllvm-22-ocaml-dev 1:22.1.6-1ubuntu3 in stonking ppc64el
        libllvm-22-ocaml-dev 1:22.1.6-1ubuntu2 in stonking riscv64
        libllvm-22-ocaml-dev 1:22.1.6-1ubuntu3 in stonking s390x
Comment: No more built by llvm-toolchain-22 1:22.1.6-1ubuntu4
Remove [y|N]? y
6 packages successfully removed.

Too late insight, I should have referred (LP: #2166916) instead and
wanted to leave this indirection here.

2. promoting the llvm binaries that are already in main in -release in
stonking-proposed

The risc64 binaries published so late, by that the -release promotion was 
complete.
Thereby those inherited the former state - the others needed this promotion.

./change-override --component main --suite stonking-proposed libclang-cpp22 
libclang1-22 libllvm22
Override component to main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking amd64: universe/libs/optional/100% 
-> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking amd64v3: 
universe/libs/optional/100% -> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking arm64: universe/libs/optional/100% 
-> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking armhf: universe/libs/optional/100% 
-> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking i386: universe/libs/optional/100% 
-> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking ppc64el: 
universe/libs/optional/100% -> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking riscv64: main/libs/optional/100% 
-> main
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking s390x: universe/libs/optional/100% 
-> main
libclang1-22 1:22.1.6-1ubuntu4 in stonking amd64: universe/libs/optional/100% 
-> main
libclang1-22 1:22.1.6-1ubuntu4 in stonking amd64v3: universe/libs/optional/100% 
-> main
libclang1-22 1:22.1.6-1ubuntu4 in stonking arm64: universe/libs/optional/100% 
-> main
libclang1-22 1:22.1.6-1ubuntu4 in stonking armhf: universe/libs/optional/100% 
-> main
libclang1-22 1:22.1.6-1ubuntu4 in stonking i386: universe/libs/optional/100% -> 
main
libclang1-22 1:22.1.6-1ubuntu4 in stonking ppc64el: universe/libs/optional/100% 
-> main
libclang1-22 1:22.1.6-1ubuntu4 in stonking riscv64: main/libs/optional/100% -> 
main
libclang1-22 1:22.1.6-1ubuntu4 in stonking s390x: universe/libs/optional/100% 
-> main
libllvm22 1:22.1.6-1ubuntu4 in stonking amd64: universe/libs/optional/100% -> 
main
libllvm22 1:22.1.6-1ubuntu4 in stonking amd64v3: universe/libs/optional/100% -> 
main
libllvm22 1:22.1.6-1ubuntu4 in stonking arm64: universe/libs/optional/100% -> 
main
libllvm22 1:22.1.6-1ubuntu4 in stonking armhf: universe/libs/optional/100% -> 
main
libllvm22 1:22.1.6-1ubuntu4 in stonking i386: universe/libs/optional/100% -> 
main
libllvm22 1:22.1.6-1ubuntu4 in stonking ppc64el: universe/libs/optional/100% -> 
main
libllvm22 1:22.1.6-1ubuntu4 in stonking riscv64: main/libs/optional/100% -> main
libllvm22 1:22.1.6-1ubuntu4 in stonking s390x: universe/libs/optional/100% -> 
main
Override [y|N]? y
libclang-cpp22 1:22.1.6-1ubuntu4 in stonking riscv64 remained the same
libclang1-22 1:22.1.6-1ubuntu4 in stonking riscv64 remained the same
libllvm22 1:22.1.6-1ubuntu4 in stonking riscv64 remained the same
21 publications overridden; 3 publications remained the same.


3. promoting the llvm source that is already in main in -release in 
stonking-proposed

./change-override --component main --suite stonking-proposed --source-only 
llvm-toolchain-22
Override component to main
llvm-toolchain-22 1:22.1.6-1ubuntu4 in stonking: universe/devel -> main
Override [y|N]? y
1 publication overridden.


AFAICS for now that should resolve this case, thanks for your cooperation in 
this complex case.
Let us see how proposed-migration, excuses and mismatches think about it after 
the next full runs.


Note @Max: I also see it starts to let go of the old (as it should) listing 
libclang-cpp21 libclang1-21 as binary movements to universe. But this triggers 
two things - first what about libllvm21?
To complete the transition I assume you want to either fully remove 21 or fully 
demote 21 - please check what is missing to get there before we release.

** Changed in: llvm-toolchain-22 (Ubuntu)
       Status: In Progress => Fix Released

-- 
You received this bug notification because you are a member of Ubuntu
Bugs, which is subscribed to Ubuntu.
https://bugs.launchpad.net/bugs/391375

Title:
  [MIR] llvm

To manage notifications about this bug go to:
https://bugs.launchpad.net/ubuntu/+source/llvm/+bug/391375/+subscriptions


-- 
ubuntu-bugs mailing list
[email protected]
https://lists.ubuntu.com/mailman/listinfo/ubuntu-bugs

Reply via email to